@@ -245,7 +245,7 @@ class Ui(object):
                    'Press enter to continue')
             log.debug('Copied private key')
             self.key_handler.copy_decrypted_private_key()
-            raw_input(format_msg(msg))
+            input_(format_msg(msg))
         self.file_crypt.del_folder_password()
         print('Folder password deleted')
 
@@ -253,7 +253,7 @@ class Ui(object):
         log.debug('View Settings Menu')
         for k, v in self.config.__dict__.items():
             print(k.ljust(20), v)
-        raw_input('Press enter to continue')
+        input_('Press enter to continue')
         return self.settings()
 
     def update_settings(self):
@@ -268,7 +268,7 @@ class Ui(object):
         print(format_msg('Then press Enter'))
         print(('1. App Name\n2. Dev Data Dir\n3. Update Url\n4. Update SSH '
                'settings\n5. Update S3 settings\n'))
-        answers = raw_input('-->')
+        answers = input_('-->')
 
         if '1' in answers:
             app_name = get_correct_answer('Enter APP NAME',
@@ -452,7 +452,7 @@ class Ui(object):
             log.error('Cannot copy decrypted config file')
         self.file_crypt.encrypt()
         msg = 'Decrypted config file copied.  Press enter to continue'
-        raw_input(format_msg(msg))
+        input_(format_msg(msg))
         self.settings()
 
     def start(self):
