@@ -33,7 +33,8 @@ from not_so_tuf.config import Config
 from not_so_tuf.downloader import FileDownloader
 from not_so_tuf.patcher import Patcher
 from not_so_tuf.utils import (ChDir, rsa_verify, _version_string_to_tuple,
-                              _version_tuple_to_string, platform_)
+                              _version_tuple_to_string, platform_, FROZEN)
+from not_so_tuf.version import __version__
 
 log = logging.getLogger(__name__)
 
@@ -113,6 +114,12 @@ class Client(object):
 
         self.name = name
         self.version = version
+
+        if FROZEN:
+            self._install_base_binary()
+            # Removes old versions of update being checked
+            self._remove_old_updates()
+
         if not self.verified:
             return False
         log.info('Checking for {} updates...'.format(name))
@@ -312,6 +319,41 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
                 log.debug('Creating directory: {}'.format(d))
                 os.mkdir(d)
 
+    def _install_base_binary(self):
+        """Zips current app and places in cache for
+        future patch updates
+        """
+        # ToDo: Get file extension dynamically
+        # ToDo: Add support for libraries
+        # Depends on if support for more archive
+        # formats are enabled.
+        filename = '{}-{}-{}.zip'.format(self.name, platform_, __version__)
+        current_version_zip = os.path.join(self.update_folder, filename)
+        if not os.path.exists(current_version_zip):
+            log.info('Added base binary v{} to updates '
+                     'folder'.format(__version__))
+            with ChDir(os.path.dirname(sys.argv[0])):
+                with ZipFile(current_version_zip, 'w') as zf:
+                    name = self.name
+                    if sys.platform == 'win32':
+                        name += '.exe'
+                    zf.write(name)
+
+    def _remove_old_updates(self):
+        """Removes old updates from cache.  Patch
+        updates start from currently installed version.
+        """
+        # ToDo: Better filename comparison
+        #       Please chime in if this is sufficient
+        #       Will remove todo if so...
+        temp = os.listdir(self.update_folder)
+        filename = '{}-{}-{}.zip'.format(self.name, platform_, __version__)
+        with ChDir(self.update_folder):
+            for t in temp:
+                if self.name in t and t < filename:
+                    log.debug('Removing old update: {}'.format(t))
+                    os.remove(t)
+
     def _check_version_file_sig(self):
         """Verifies version file signature"""
         if self.json_data is None:
