@@ -289,19 +289,22 @@ class PackageHandler(object):
 
             self.json_data['latest'][name] = version
 
-    def _get_package_list(self):
+    def _get_package_list(self, ignore_errors=True):
         """Adds compatible packages to internal package manifest
         for futher processing
         """
         # Process all packages in new folder and gets
         # url md5 and some outer info.
         log.info('Getting package list')
+        bad_packages = []
         patch_manifest = []
         with ChDir(self.new_dir):
             packages = os.listdir(os.getcwd())
             for p in packages:
-                if os.path.splitext(p)[1].lower() not in \
+                if self._package_plat_version_check(p) is False or \
+                    os.path.splitext(p)[1].lower() not in \
                         self.supported_extensions:
+                    bad_packages.append(p)
                     continue
                 self._update_file_list(p)
                 p_version = self._get_version_number(p)
@@ -337,6 +340,16 @@ class PackageHandler(object):
                         s['patch_name'] = i[1]
                         s['patch_md5'] = _get_package_hashes(i[1])
                         break
+        if ignore_errors is False:
+            print 'Bad package names'
+            for b in bad_packages:
+                print b
+
+    def _package_plat_version_check(self, package):
+        found = re.findall('-[macnixw64]{3,5}-[0-9]+\.[0-9]+\.[0-9]', package)
+        if len(found) < 1:
+            return False
+        return True
 
     def _get_platform(self, name):
         platform_name = re.compile('[macnixw64]{3,5}').findall(name)[0]
